@@ -1,5 +1,4 @@
-//! Types for EPP contact check request
-
+/// Types for EPP contact check request
 use epp_client_macros::*;
 
 use crate::epp::object::{ElementName, EppObject, StringValue, StringValueTrait};
@@ -11,16 +10,33 @@ use serde::{Deserialize, Serialize};
 ///
 /// ## Usage
 ///
-/// ```rust
+/// ```no_run
+/// use std::collections::HashMap;
+///
+/// use epp_client::config::{EppClientConfig, EppClientConnection};
 /// use epp_client::EppClient;
 /// use epp_client::epp::{EppContactCheck, EppContactCheckResponse};
 /// use epp_client::epp::generate_client_tr_id;
 ///
 /// #[tokio::main]
 /// async fn main() {
-///     // Create an instance of EppClient, specifying the name of the registry as in
-///     // the config file
-///     let mut client = match EppClient::new("verisign").await {
+///     // Create a config
+///     let mut registry: HashMap<String, EppClientConnection> = HashMap::new();
+///     registry.insert(
+///         "registry_name".to_owned(),
+///         EppClientConnection {
+///             host: "example.com".to_owned(),
+///             port: 700,
+///             username: "username".to_owned(),
+///             password: "password".to_owned(),
+///             ext_uris: None,
+///             tls_files: None,
+///         },
+///     );
+///     let config = EppClientConfig { registry };
+///
+///     // Create an instance of EppClient, passing the config
+///     let mut client = match EppClient::new(&config, "registry_name").await {
 ///         Ok(client) => client,
 ///         Err(e) => panic!("Failed to create EppClient: {}",  e)
 ///     };
@@ -35,6 +51,8 @@ use serde::{Deserialize, Serialize};
 ///     let response = client.transact::<_, EppContactCheckResponse>(&contact_check).await.unwrap();
 ///
 ///     println!("{:?}", response);
+///
+///     client.logout().await.unwrap();
 /// }
 /// ```
 pub type EppContactCheck = EppObject<Command<ContactCheck>>;
@@ -63,13 +81,13 @@ impl EppContactCheck {
     pub fn new(contact_ids: Vec<&str>, client_tr_id: &str) -> EppContactCheck {
         let contact_ids = contact_ids
             .iter()
-            .filter_map(|d| Some(d.to_string_value()))
+            .map(|d| d.to_string_value())
             .collect::<Vec<StringValue>>();
 
         let contact_check = ContactCheck {
             list: ContactList {
                 xmlns: EPP_CONTACT_XMLNS.to_string(),
-                contact_ids: contact_ids,
+                contact_ids,
             },
         };
 
