@@ -14,16 +14,34 @@ use serde::{Deserialize, Serialize};
 ///
 /// ## Usage
 ///
-/// ```ignore
+/// ```no_run
+/// use std::collections::HashMap;
+///
+/// use epp_client::config::{EppClientConfig, EppClientConnection};
 /// use epp_client::EppClient;
 /// use epp_client::epp::{EppContactUpdate, EppContactUpdateResponse};
 /// use epp_client::epp::generate_client_tr_id;
+/// use epp_client::epp::object::data::ContactStatus;
 ///
 /// #[tokio::main]
 /// async fn main() {
-///     // Create an instance of EppClient, specifying the name of the registry as in
-///     // the config file
-///     let mut client = match EppClient::new("verisign").await {
+///     // Create a config
+///     let mut registry: HashMap<String, EppClientConnection> = HashMap::new();
+///     registry.insert(
+///         "registry_name".to_owned(),
+///         EppClientConnection {
+///             host: "example.com".to_owned(),
+///             port: 700,
+///             username: "username".to_owned(),
+///             password: "password".to_owned(),
+///             ext_uris: None,
+///             tls_files: None,
+///         },
+///     );
+///     let config = EppClientConfig { registry };
+///
+///     // Create an instance of EppClient, passing the config and the registry you want to connect to
+///     let mut client = match EppClient::new(&config, "registry_name").await {
 ///         Ok(client) => client,
 ///         Err(e) => panic!("Failed to create EppClient: {}",  e)
 ///     };
@@ -46,6 +64,8 @@ use serde::{Deserialize, Serialize};
 ///     let response = client.transact::<_, EppContactUpdateResponse>(&contact_update).await.unwrap();
 ///
 ///     println!("{:?}", response);
+///
+///     client.logout().await.unwrap();
 /// }
 /// ```
 pub type EppContactUpdate = EppObject<Command<ContactUpdate>>;
@@ -124,9 +144,8 @@ impl EppContactUpdate {
 
     /// Sets the data for the &lt;fax&gt; tag under &lt;chg&gt; for the contact update request
     pub fn set_fax(&mut self, fax: Phone) {
-        match &mut self.data.command.contact.change_info {
-            Some(ref mut info) => info.fax = Some(fax),
-            _ => (),
+        if let Some(info) = &mut self.data.command.contact.change_info {
+            info.fax = Some(fax)
         }
     }
 
@@ -151,7 +170,7 @@ impl EppContactUpdate {
                     email: Some(res_data.info_data.email.clone()),
                     postal_info: Some(res_data.info_data.postal_info.clone()),
                     voice: Some(res_data.info_data.voice.clone()),
-                    fax: res_data.info_data.fax.clone(),
+                    fax: res_data.info_data.fax,
                     auth_info: None,
                 });
                 Ok(())
