@@ -11,16 +11,33 @@ use serde::{Deserialize, Serialize};
 ///
 /// ## Usage
 ///
-/// ```rust
+/// ```no_run
+/// use std::collections::HashMap;
+///
+/// use epp_client::config::{EppClientConfig, EppClientConnection};
 /// use epp_client::EppClient;
 /// use epp_client::epp::{EppDomainCheck, EppDomainCheckResponse};
 /// use epp_client::epp::generate_client_tr_id;
 ///
 /// #[tokio::main]
 /// async fn main() {
-///     // Create an instance of EppClient, specifying the name of the registry as in
-///     // the config file
-///     let mut client = match EppClient::new("verisign").await {
+///     // Create a config
+///     let mut registry: HashMap<String, EppClientConnection> = HashMap::new();
+///     registry.insert(
+///         "registry_name".to_owned(),
+///         EppClientConnection {
+///             host: "example.com".to_owned(),
+///             port: 700,
+///             username: "username".to_owned(),
+///             password: "password".to_owned(),
+///             ext_uris: None,
+///             tls_files: None,
+///         },
+///     );
+///     let config = EppClientConfig { registry };
+///
+///     // Create an instance of EppClient, passing the config and the registry you want to connect to
+///     let mut client = match EppClient::new(&config, "registry_name").await {
 ///         Ok(client) => client,
 ///         Err(e) => panic!("Failed to create EppClient: {}",  e)
 ///     };
@@ -35,6 +52,8 @@ use serde::{Deserialize, Serialize};
 ///     let response = client.transact::<_, EppDomainCheckResponse>(&domain_check).await.unwrap();
 ///
 ///     println!("{:?}", response);
+///
+///     client.logout().await.unwrap();
 /// }
 /// ```
 pub type EppDomainCheck = EppObject<Command<DomainCheck>>;
@@ -63,13 +82,13 @@ impl EppDomainCheck {
     pub fn new(domains: Vec<&str>, client_tr_id: &str) -> EppDomainCheck {
         let domains = domains
             .iter()
-            .filter_map(|d| Some(d.to_string_value()))
+            .map(|d| d.to_string_value())
             .collect::<Vec<StringValue>>();
 
         let domain_check = DomainCheck {
             list: DomainList {
                 xmlns: EPP_DOMAIN_XMLNS.to_string(),
-                domains: domains,
+                domains,
             },
         };
 
